@@ -44,19 +44,19 @@ def general_request(method: str, url: str, **kwargs) -> str:
         return r.text
     except ConnectionError as exc:
         error_type = str(exc)
-        logging.error('Netowork error (DNS, refused connection, etc)')
+        logging.error(f'Netowork error (DNS, refused connection, etc) - {method} {url} {kwargs}')
         raise Exception("Netowork error (DNS, refused connection, etc)")
     except HTTPError as exc:
         error_type = str(exc)
-        logging.error(f"{r.status_code} {r.reason}")
+        logging.error(f"{r.status_code} {r.reason} - {method} {url} {kwargs}")
         raise Exception(f"{r.status_code} {r.reason}")
     except TimeoutError as exc:
         error_type = str(exc)
-        logging.error("Timeout error from API")
+        logging.error(f"Timeout error from API - {method} {url} {kwargs}")
         raise Exception("Timeout error from API")
     except RequestException as exc:
         error_type = str(exc)
-        logging.error("General error in getting data from API")
+        logging.error(f"General error in getting data from API - {method} {url} {kwargs}")
         raise Exception("General error in getting data from API")
 
 
