@@ -2,10 +2,10 @@ from dataclasses import dataclass
 
 
 @dataclass
-class WorkingDir():
+class WorkingDir:
 
     path: str
 
     @property
     def get_path(self) -> str:
-        return self.path
\ No newline at end of file
+        return self.path
